@@ -17,7 +17,6 @@
 # limitations under the License.
 from __future__ import annotations
 
-import functools
 import hashlib
 import logging
 import re
@@ -59,8 +58,9 @@ from eodag.utils import (
     deepcopy,
     dict_items_recursive_sort,
     get_geometry_from_various,
-    is_range_in_range,
 )
+from eodag.utils.cache import instance_cached_method
+from eodag.utils.dates import is_range_in_range
 from eodag.utils.exceptions import DownloadError, NotAvailableError, ValidationError
 from eodag.utils.requests import fetch_json
 
@@ -94,6 +94,7 @@ ECMWF_KEYWORDS = {
     "fcperiod",
     "fieldset",
     "filter",
+    "feature",
     "format",
     "frame",
     "frequency",
@@ -317,17 +318,17 @@ def append_time(input_date: date, time: Optional[str]) -> datetime:
 
 
 def parse_date(
-    date_str: str, time: Optional[Union[str, list[str]]]
+    date: str, time: Optional[Union[str, list[str]]]
 ) -> tuple[datetime, datetime]:
     """Parses a date string in formats YYYY-MM-DD, YYYMMDD, solo or in start/end or start/to/end intervals."""
-    if "to" in date_str:
-        start_date_str, end_date_str = date_str.split("/to/")
-    elif "/" in date_str:
-        dates = date_str.split("/")
+    if "to" in date:
+        start_date_str, end_date_str = date.split("/to/")
+    elif "/" in date:
+        dates = date.split("/")
         start_date_str = dates[0]
         end_date_str = dates[-1]
     else:
-        start_date_str = end_date_str = date_str
+        start_date_str = end_date_str = date
 
     # Update YYYYMMDD formatted dates
     if re.match(r"^\d{8}$", start_date_str):
@@ -401,10 +402,11 @@ def ecmwf_temporal_to_eodag(
     start = end = None
 
     if date := params.get("date"):
+        if isinstance(date, list):
+            date = "/".join(date)
         start, end = parse_date(date, params.get("time"))
 
-    elif year := params.get("year") or params.get("hyear"):
-        year = params.get("year") or params.get("hyear")
+    elif year := (params.get("year") or params.get("hyear")):
         month = params.get("month") or params.get("hmonth")
         day = params.get("day") or params.get("hday")
         time = params.get("time")
@@ -470,7 +472,7 @@ class ECMWFSearch(PostJsonSearch):
         self.config.__dict__.setdefault(
             "discover_metadata",
             {
-                "auto_discovery": True,
+                "auto_discovery": False,
                 "search_param": "{metadata}",
                 "metadata_pattern": "^[a-zA-Z0-9][a-zA-Z0-9_]*$",
             },
@@ -499,7 +501,7 @@ class ECMWFSearch(PostJsonSearch):
         """
         product_type = prep.product_type
         if not product_type:
-            product_type = kwargs.get("productType", None)
+            product_type = kwargs.get("productType")
         kwargs = self._preprocess_search_params(kwargs, product_type)
         result, num_items = super().query(prep, **kwargs)
         if prep.count and not num_items:
@@ -547,7 +549,9 @@ class ECMWFSearch(PostJsonSearch):
         :param params: Search parameters to be preprocessed.
         :param product_type: (optional) product type id
         """
-        _dc_qs = params.get("_dc_qs", None)
+
+        _dc_qs = params.get("_dc_qs")
+
         if _dc_qs is not None:
             # if available, update search params using datacube query-string
             _dc_qp = geojson.loads(unquote_plus(unquote_plus(_dc_qs)))
@@ -557,7 +561,7 @@ class ECMWFSearch(PostJsonSearch):
                 (params[START], params[END],) = _dc_qp[
                     "date"
                 ].split("/")
-            elif _dc_qp.get("date", None):
+            elif _dc_qp.get("date"):
                 params[START] = params[END] = _dc_qp["date"]
 
             if "/" in _dc_qp.get("area", ""):
@@ -652,6 +656,9 @@ class ECMWFSearch(PostJsonSearch):
                             "missionEndDate", today().isoformat()
                         )
                     )
+                else:
+                    keywords[START] = start
+                    keywords[END] = end
 
     def _get_product_type_queryables(
         self, product_type: Optional[str], alias: Optional[str], filters: dict[str, Any]
@@ -720,7 +727,7 @@ class ECMWFSearch(PostJsonSearch):
                 "geometry",
             }:
                 raise ValidationError(
-                    f"{key} is not a queryable parameter for {self.provider}"
+                    f"'{key}' is not a queryable parameter for {self.provider}", {key}
                 )
 
             formated_filters[key] = v
@@ -779,7 +786,9 @@ class ECMWFSearch(PostJsonSearch):
                 and keyword.removeprefix(ECMWF_PREFIX)
                 not in set(list(available_values.keys()) + [f["name"] for f in form])
             ):
-                raise ValidationError(f"{keyword} is not a queryable parameter")
+                raise ValidationError(
+                    f"'{keyword}' is not a queryable parameter", {keyword}
+                )
 
         # generate queryables
         if form:
@@ -866,7 +875,8 @@ class ECMWFSearch(PostJsonSearch):
             # we only compare list of strings.
             if isinstance(values, dict):
                 raise ValidationError(
-                    f"Parameter value as object is not supported: {keyword}={values}"
+                    f"Parameter value as object is not supported: {keyword}={values}",
+                    {keyword},
                 )
 
             # We convert every single value to a list of string
@@ -932,7 +942,10 @@ class ECMWFSearch(PostJsonSearch):
                 raise ValidationError(
                     f"{keyword}={values} is not available"
                     f"{all_keywords_str}."
-                    f" Allowed values are {', '.join(allowed_values)}."
+                    f" Allowed values are {', '.join(allowed_values)}.",
+                    set(
+                        [keyword] + [k for k in parsed_keywords if k in input_keywords]
+                    ),
                 )
 
             parsed_keywords.append(keyword)
@@ -1091,6 +1104,7 @@ class ECMWFSearch(PostJsonSearch):
 
         return qp
 
+    @instance_cached_method()
     def _fetch_data(self, url: str) -> Any:
         """
         fetches from a provider elements like constraints or forms.
@@ -1107,7 +1121,7 @@ class ECMWFSearch(PostJsonSearch):
             else None
         )
         timeout = getattr(self.config, "timeout", DEFAULT_SEARCH_TIMEOUT)
-        return functools.lru_cache()(fetch_json)(url, auth=auth, timeout=timeout)
+        return fetch_json(url, auth=auth, timeout=timeout)
 
     def normalize_results(
         self, results: RawSearchResult, **kwargs: Any
@@ -1176,6 +1190,9 @@ class ECMWFSearch(PostJsonSearch):
                 + "_ORDERABLE_"
                 + query_hash
             )
+            # use product_type_config as default properties
+            product_type_config = getattr(self.config, "product_type_config", {})
+            properties = dict(product_type_config, **properties)
 
         qs = geojson.dumps(sorted_unpaginated_qp)
 
@@ -1219,6 +1236,9 @@ def _check_id(product: EOProduct) -> EOProduct:
     if not (product_id := product.search_kwargs.get("id")):
         return product
 
+    if "ORDERABLE" in product_id:
+        return product
+
     on_response_mm = getattr(product.downloader.config, "order_on_response", {}).get(
         "metadata_mapping", {}
     )
@@ -1249,7 +1269,7 @@ def _check_id(product: EOProduct) -> EOProduct:
             isinstance(e, DownloadError) or isinstance(e, ValidationError)
         ) and "order status could not be checked" in e.args[0]:
             raise ValidationError(
-                f"Item {product_id} does not exist with {product.provider}."
+                f"Requested data is not available on {product.provider} ({product_id})."
             ) from e
         raise ValidationError(e.args[0]) from e
 
@@ -1439,6 +1459,9 @@ class MeteoblueSearch(ECMWFSearch):
             productType=product_type,
             properties=properties,
         )
+        # use product_type_config as default properties
+        product_type_config = getattr(self.config, "product_type_config", {})
+        product.properties = dict(product_type_config, **product.properties)
 
         return [
             product,
