@@ -24,7 +24,6 @@ this package should go here
 from __future__ import annotations
 
 import ast
-import datetime
 import errno
 import functools
 import hashlib
@@ -43,8 +42,7 @@ import unicodedata
 import warnings
 from collections import defaultdict
 from copy import deepcopy as copy_deepcopy
-from dataclasses import dataclass
-from datetime import datetime as dt
+from dataclasses import dataclass, field
 from email.message import Message
 from glob import glob
 from importlib.metadata import metadata
@@ -75,8 +73,6 @@ import orjson
 import shapefile
 import shapely.wkt
 import yaml
-from dateutil.parser import isoparse
-from dateutil.tz import UTC
 from jsonpath_ng import jsonpath
 from jsonpath_ng.ext import parse
 from jsonpath_ng.jsonpath import Child, Fields, Index, Root, Slice
@@ -414,54 +410,6 @@ def maybe_generator(obj: Any) -> Iterator[Any]:
         yield obj
 
 
-def get_timestamp(date_time: str) -> float:
-    """Return the Unix timestamp of an ISO8601 date/datetime in seconds.
-
-    If the datetime has no offset, it is assumed to be an UTC datetime.
-
-    :param date_time: The datetime string to return as timestamp
-    :returns: The timestamp corresponding to the ``date_time`` string in seconds
-    """
-    dt = isoparse(date_time)
-    if not dt.tzinfo:
-        dt = dt.replace(tzinfo=UTC)
-    return dt.timestamp()
-
-
-def datetime_range(start: dt, end: dt) -> Iterator[dt]:
-    """Generator function for all dates in-between ``start`` and ``end`` date."""
-    delta = end - start
-    for nday in range(delta.days + 1):
-        yield start + datetime.timedelta(days=nday)
-
-
-def is_range_in_range(valid_range: str, check_range: str) -> bool:
-    """Check if the check_range is completely within the valid_range.
-
-    This function checks if both the start and end dates of the check_range
-    are within the start and end dates of the valid_range.
-
-    :param valid_range: The valid date range in the format 'YYYY-MM-DD/YYYY-MM-DD'.
-    :param check_range: The date range to check in the format 'YYYY-MM-DD/YYYY-MM-DD'.
-    :returns: True if check_range is within valid_range, otherwise False.
-    """
-    if "/" not in valid_range or "/" not in check_range:
-        return False
-
-    # Split the date ranges into start and end dates
-    start_valid, end_valid = valid_range.split("/")
-    start_check, end_check = check_range.split("/")
-
-    # Convert the strings to datetime objects using fromisoformat
-    start_valid_dt = datetime.datetime.fromisoformat(start_valid)
-    end_valid_dt = datetime.datetime.fromisoformat(end_valid)
-    start_check_dt = datetime.datetime.fromisoformat(start_check)
-    end_check_dt = datetime.datetime.fromisoformat(end_check)
-
-    # Check if check_range is within valid_range
-    return start_valid_dt <= start_check_dt and end_valid_dt >= end_check_dt
-
-
 class DownloadedCallback:
     """Example class for callback after each download in :meth:`~eodag.api.core.EODataAccessGateway.download_all`"""
 
@@ -1457,9 +1405,76 @@ class StreamResponse:
     """Represents a streaming response"""
 
     content: Iterable[bytes]
-    headers: Optional[Mapping[str, str]] = None
+    _filename: Optional[str] = field(default=None, repr=False, init=False)
+    _size: Optional[int] = field(default=None, repr=False, init=False)
+    headers: dict[str, str] = field(default_factory=dict)
     media_type: Optional[str] = None
     status_code: Optional[int] = None
+    arcname: Optional[str] = None
+
+    def __init__(
+        self,
+        content: Iterable[bytes],
+        filename: Optional[str] = None,
+        size: Optional[int] = None,
+        headers: Optional[Mapping[str, str]] = None,
+        media_type: Optional[str] = None,
+        status_code: Optional[int] = None,
+        arcname: Optional[str] = None,
+    ):
+        self.content = content
+        self.headers = dict(headers) if headers else {}
+        self.media_type = media_type
+        self.status_code = status_code
+        self.arcname = arcname
+        # use property setters to update headers
+        self.filename = filename
+        self.size = size
+
+    # filename handling
+    @property
+    def filename(self) -> Optional[str]:
+        """Get the filename for the streaming response.
+
+        :returns: The filename, or None if not set
+        """
+        return self._filename
+
+    @filename.setter
+    def filename(self, value: Optional[str]) -> None:
+        """Set the filename and update the content-disposition header accordingly.
+
+        :param value: The filename to set, or None to clear it
+        """
+        self._filename = value
+        if value:
+            outputs_filename = os.path.basename(value)
+            self.headers[
+                "content-disposition"
+            ] = f'attachment; filename="{outputs_filename}"'
+        elif "content-disposition" in self.headers:
+            del self.headers["content-disposition"]
+
+    # size handling
+    @property
+    def size(self) -> Optional[int]:
+        """Get the content size for the streaming response.
+
+        :returns: The content size in bytes, or None if not set
+        """
+        return self._size
+
+    @size.setter
+    def size(self, value: Optional[int]) -> None:
+        """Set the content size and update the content-length header accordingly.
+
+        :param value: The content size in bytes, or None to clear it
+        """
+        self._size = value
+        if value is not None:
+            self.headers["content-length"] = str(value)
+        elif "content-length" in self.headers:
+            del self.headers["content-length"]
 
 
 def guess_file_type(file: str) -> Optional[str]:
