@@ -85,7 +85,6 @@ from eodag.utils import (
     USER_AGENT,
     get_bucket_name_and_prefix,
     get_geometry_from_various,
-    get_timestamp,
     makedirs,
     merge_mappings,
     path_to_uri,
@@ -104,6 +103,7 @@ from eodag.utils import (
     cached_yaml_load_all,
     StreamResponse,
 )
+from eodag.utils.dates import get_timestamp
 from eodag.utils.env import is_env_var_true
 from eodag.utils.requests import fetch_json
 from eodag.utils.s3 import (
@@ -116,7 +116,6 @@ from eodag.utils.s3 import (
     _prepare_file_in_zip,
     _compute_file_ranges,
     stream_download_from_s3,
-    _build_stream_response,
 )
 
 
