@@ -68,13 +68,6 @@ EARTH_SEARCH_SEARCH_ARGS = [
     "2020-01-15",
     [0.2563590566012408, 43.19555008715042, 2.379835675499976, 43.907759172380565],
 ]
-EARTH_SEARCH_COG_SEARCH_ARGS = [
-    "earth_search_cog",
-    "S2_MSI_L2A_COG",
-    "2020-01-01",
-    "2020-01-15",
-    [0.2563590566012408, 43.19555008715042, 2.379835675499976, 43.907759172380565],
-]
 EARTH_SEARCH_GCS_SEARCH_ARGS = [
     "earth_search_gcs",
     "S2_MSI_L1C",
@@ -486,11 +479,6 @@ class TestEODagEndToEnd(EndToEndBase):
         expected_filename = "{}".format(product.properties["title"])
         self.execute_download(product, expected_filename, wait_sec=15)
 
-    def test_end_to_end_search_download_earth_search_cog(self):
-        product = self.execute_search(*EARTH_SEARCH_COG_SEARCH_ARGS)
-        expected_filename = "{}".format(product.properties["title"])
-        self.execute_download(product, expected_filename, wait_sec=20)
-
     def test_end_to_end_search_download_earth_search_gcs(self):
         product = self.execute_search(*EARTH_SEARCH_GCS_SEARCH_ARGS)
         expected_filename = "{}".format(product.properties["title"])
@@ -705,12 +693,6 @@ class TestEODagEndToEnd(EndToEndBase):
                 ext_product_types_conf[provider]["providers_config"],
             )
 
-    def test_end_to_end_discover_product_types_earth_search_cog(self):
-        """discover_product_types() must return None for earth_search_cog"""
-        provider = "earth_search_cog"
-        ext_product_types_conf = self.eodag.discover_product_types(provider=provider)
-        self.assertIsNone(ext_product_types_conf[provider])
-
     def test_end_to_end_discover_product_types_earth_search_gcs(self):
         """discover_product_types() must return None for earth_search_gcs"""
         provider = "earth_search_gcs"
